@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings FATAL => 'all';
 use Text::Spintax::Mo;
-use Text::Spintax::parser;
+use Text::Spintax::grammar;
 use Text::Spintax::RenderNode;
 use Parse::Lex;
 
@@ -14,11 +14,11 @@ Text::Spintax - A parser and renderer for spintax formatted text.
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 
 =head1 SYNOPSIS
@@ -98,7 +98,7 @@ sub parse {
    }
    $lexer->from($text);
 
-   my $parser = new parser();
+   my $parser = new Text::Spintax::grammar();
    $parser->YYData->{lexer} = $lexer;
    my $root = Text::Spintax::RenderNode->new(type => "sequence", weight => 1);
    $self->root($root);
